// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_waylandbackend.cpp"
#include "EWIEGA46WW/moc_waylandconfig.cpp"
#include "EWIEGA46WW/moc_waylandoutputdevice.cpp"
#include "EWIEGA46WW/moc_waylandoutputdevicemode.cpp"
#include "EWIEGA46WW/moc_waylandoutputmanagement.cpp"
#include "EWIEGA46WW/moc_waylandscreen.cpp"
