/****************************************************************************
** Meta object code from reading C++ file 'xcbeventlistener.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../libkscreen-5.27.12/backends/xcbeventlistener.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'xcbeventlistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_XCBEventListener_t {
    QByteArrayData data[22];
    char stringdata0[274];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_XCBEventListener_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_XCBEventListener_t qt_meta_stringdata_XCBEventListener = {
    {
QT_MOC_LITERAL(0, 0, 16), // "XCBEventListener"
QT_MOC_LITERAL(1, 17, 13), // "screenChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 20), // "xcb_randr_rotation_t"
QT_MOC_LITERAL(4, 53, 8), // "rotation"
QT_MOC_LITERAL(5, 62, 6), // "sizePx"
QT_MOC_LITERAL(6, 69, 6), // "sizeMm"
QT_MOC_LITERAL(7, 76, 14), // "outputsChanged"
QT_MOC_LITERAL(8, 91, 11), // "crtcChanged"
QT_MOC_LITERAL(9, 103, 16), // "xcb_randr_crtc_t"
QT_MOC_LITERAL(10, 120, 4), // "crtc"
QT_MOC_LITERAL(11, 125, 16), // "xcb_randr_mode_t"
QT_MOC_LITERAL(12, 142, 4), // "mode"
QT_MOC_LITERAL(13, 147, 4), // "geom"
QT_MOC_LITERAL(14, 152, 15), // "xcb_timestamp_t"
QT_MOC_LITERAL(15, 168, 9), // "timestamp"
QT_MOC_LITERAL(16, 178, 13), // "outputChanged"
QT_MOC_LITERAL(17, 192, 18), // "xcb_randr_output_t"
QT_MOC_LITERAL(18, 211, 6), // "output"
QT_MOC_LITERAL(19, 218, 22), // "xcb_randr_connection_t"
QT_MOC_LITERAL(20, 241, 10), // "connection"
QT_MOC_LITERAL(21, 252, 21) // "outputPropertyChanged"

    },
    "XCBEventListener\0screenChanged\0\0"
    "xcb_randr_rotation_t\0rotation\0sizePx\0"
    "sizeMm\0outputsChanged\0crtcChanged\0"
    "xcb_randr_crtc_t\0crtc\0xcb_randr_mode_t\0"
    "mode\0geom\0xcb_timestamp_t\0timestamp\0"
    "outputChanged\0xcb_randr_output_t\0"
    "output\0xcb_randr_connection_t\0connection\0"
    "outputPropertyChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_XCBEventListener[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   39,    2, 0x06 /* Public */,
       7,    0,   46,    2, 0x06 /* Public */,
       8,    5,   47,    2, 0x06 /* Public */,
      16,    4,   58,    2, 0x06 /* Public */,
      21,    1,   67,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QSize, QMetaType::QSize,    4,    5,    6,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9, 0x80000000 | 11, 0x80000000 | 3, QMetaType::QRect, 0x80000000 | 14,   10,   12,    4,   13,   15,
    QMetaType::Void, 0x80000000 | 17, 0x80000000 | 9, 0x80000000 | 11, 0x80000000 | 19,   18,   10,   12,   20,
    QMetaType::Void, 0x80000000 | 17,   18,

       0        // eod
};

void XCBEventListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<XCBEventListener *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->screenChanged((*reinterpret_cast< xcb_randr_rotation_t(*)>(_a[1])),(*reinterpret_cast< const QSize(*)>(_a[2])),(*reinterpret_cast< const QSize(*)>(_a[3]))); break;
        case 1: _t->outputsChanged(); break;
        case 2: _t->crtcChanged((*reinterpret_cast< xcb_randr_crtc_t(*)>(_a[1])),(*reinterpret_cast< xcb_randr_mode_t(*)>(_a[2])),(*reinterpret_cast< xcb_randr_rotation_t(*)>(_a[3])),(*reinterpret_cast< const QRect(*)>(_a[4])),(*reinterpret_cast< xcb_timestamp_t(*)>(_a[5]))); break;
        case 3: _t->outputChanged((*reinterpret_cast< xcb_randr_output_t(*)>(_a[1])),(*reinterpret_cast< xcb_randr_crtc_t(*)>(_a[2])),(*reinterpret_cast< xcb_randr_mode_t(*)>(_a[3])),(*reinterpret_cast< xcb_randr_connection_t(*)>(_a[4]))); break;
        case 4: _t->outputPropertyChanged((*reinterpret_cast< xcb_randr_output_t(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (XCBEventListener::*)(xcb_randr_rotation_t , const QSize & , const QSize & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&XCBEventListener::screenChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (XCBEventListener::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&XCBEventListener::outputsChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (XCBEventListener::*)(xcb_randr_crtc_t , xcb_randr_mode_t , xcb_randr_rotation_t , const QRect & , xcb_timestamp_t );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&XCBEventListener::crtcChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (XCBEventListener::*)(xcb_randr_output_t , xcb_randr_crtc_t , xcb_randr_mode_t , xcb_randr_connection_t );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&XCBEventListener::outputChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (XCBEventListener::*)(xcb_randr_output_t );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&XCBEventListener::outputPropertyChanged)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject XCBEventListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_XCBEventListener.data,
    qt_meta_data_XCBEventListener,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *XCBEventListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *XCBEventListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_XCBEventListener.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QAbstractNativeEventFilter"))
        return static_cast< QAbstractNativeEventFilter*>(this);
    return QObject::qt_metacast(_clname);
}

int XCBEventListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void XCBEventListener::screenChanged(xcb_randr_rotation_t _t1, const QSize & _t2, const QSize & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void XCBEventListener::outputsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void XCBEventListener::crtcChanged(xcb_randr_crtc_t _t1, xcb_randr_mode_t _t2, xcb_randr_rotation_t _t3, const QRect & _t4, xcb_timestamp_t _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void XCBEventListener::outputChanged(xcb_randr_output_t _t1, xcb_randr_crtc_t _t2, xcb_randr_mode_t _t3, xcb_randr_connection_t _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void XCBEventListener::outputPropertyChanged(xcb_randr_output_t _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
