/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -a fakebackendadaptor -i fake.h -l Fake /build/libkscreen5/src/libkscreen-5.27.12/interfaces/org.kde.KScreen.FakeBackend.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef FAKEBACKENDADAPTOR_H
#define FAKEBACKENDADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "fake.h"
QT_BEGIN_NAMESPACE
class QByteArray;
template<class T> class QList;
template<class Key, class Value> class QMap;
class QString;
class QStringList;
class QVariant;
QT_END_NAMESPACE

/*
 * Adaptor class for interface org.kde.kscreen.FakeBackend
 */
class FakeBackendAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.kscreen.FakeBackend")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.kscreen.FakeBackend\">\n"
"    <method name=\"setConnected\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"connected\"/>\n"
"    </method>\n"
"    <method name=\"setEnabled\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"enabled\"/>\n"
"    </method>\n"
"    <method name=\"setPrimary\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"primary\"/>\n"
"    </method>\n"
"    <method name=\"setCurrentModeId\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"currentModeId\"/>\n"
"    </method>\n"
"    <method name=\"setRotation\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"rotation\"/>\n"
"    </method>\n"
"    <method name=\"addOutput\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"    </method>\n"
"    <method name=\"removeOutput\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"outputId\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    FakeBackendAdaptor(Fake *parent);
    virtual ~FakeBackendAdaptor();

    inline Fake *parent() const
    { return static_cast<Fake *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void addOutput(int outputId, const QString &name);
    void removeOutput(int outputId);
    void setConnected(int outputId, bool connected);
    void setCurrentModeId(int outputId, const QString &currentModeId);
    void setEnabled(int outputId, bool enabled);
    void setPrimary(int outputId, bool primary);
    void setRotation(int outputId, int rotation);
Q_SIGNALS: // SIGNALS
};

#endif
