// This file was generated by qtwaylandscanner
// source file is /usr/share/plasma-wayland-protocols/kde-output-order-v1.xml

#ifndef QT_WAYLAND_KDE_OUTPUT_ORDER_V1
#define QT_WAYLAND_KDE_OUTPUT_ORDER_V1

#include "wayland-kde-output-order-v1-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")

namespace QtWayland {
    class  kde_output_order_v1
    {
    public:
        kde_output_order_v1(struct ::wl_registry *registry, int id, int version);
        kde_output_order_v1(struct ::kde_output_order_v1 *object);
        kde_output_order_v1();

        virtual ~kde_output_order_v1();

        void init(struct ::wl_registry *registry, int id, int version);
        void init(struct ::kde_output_order_v1 *object);

        struct ::kde_output_order_v1 *object() { return m_kde_output_order_v1; }
        const struct ::kde_output_order_v1 *object() const { return m_kde_output_order_v1; }
        static kde_output_order_v1 *fromObject(struct ::kde_output_order_v1 *object);

        bool isInitialized() const;

        static const struct ::wl_interface *interface();

        void destroy();

    protected:
        virtual void kde_output_order_v1_output(const QString &output_name);
        virtual void kde_output_order_v1_done();

    private:
        void init_listener();
        static const struct kde_output_order_v1_listener m_kde_output_order_v1_listener;
        static void handle_output(
            void *data,
            struct ::kde_output_order_v1 *object,
            const char *output_name);
        static void handle_done(
            void *data,
            struct ::kde_output_order_v1 *object);
        struct ::kde_output_order_v1 *m_kde_output_order_v1;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
