/****************************************************************************
** Meta object code from reading C++ file 'output.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../libkscreen-5.27.12/src/output.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'output.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KScreen__Output_t {
    QByteArrayData data[88];
    char stringdata0[926];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__Output_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__Output_t qt_meta_stringdata_KScreen__Output = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KScreen::Output"
QT_MOC_LITERAL(1, 16, 27), // "RegisterEnumClassesUnscoped"
QT_MOC_LITERAL(2, 44, 5), // "false"
QT_MOC_LITERAL(3, 50, 13), // "outputChanged"
QT_MOC_LITERAL(4, 64, 0), // ""
QT_MOC_LITERAL(5, 65, 10), // "posChanged"
QT_MOC_LITERAL(6, 76, 11), // "sizeChanged"
QT_MOC_LITERAL(7, 88, 20), // "currentModeIdChanged"
QT_MOC_LITERAL(8, 109, 15), // "rotationChanged"
QT_MOC_LITERAL(9, 125, 18), // "isConnectedChanged"
QT_MOC_LITERAL(10, 144, 16), // "isEnabledChanged"
QT_MOC_LITERAL(11, 161, 15), // "priorityChanged"
QT_MOC_LITERAL(12, 177, 13), // "clonesChanged"
QT_MOC_LITERAL(13, 191, 24), // "replicationSourceChanged"
QT_MOC_LITERAL(14, 216, 12), // "scaleChanged"
QT_MOC_LITERAL(15, 229, 26), // "explicitLogicalSizeChanged"
QT_MOC_LITERAL(16, 256, 26), // "followPreferredModeChanged"
QT_MOC_LITERAL(17, 283, 19), // "followPreferredMode"
QT_MOC_LITERAL(18, 303, 19), // "capabilitiesChanged"
QT_MOC_LITERAL(19, 323, 15), // "overscanChanged"
QT_MOC_LITERAL(20, 339, 16), // "vrrPolicyChanged"
QT_MOC_LITERAL(21, 356, 15), // "rgbRangeChanged"
QT_MOC_LITERAL(22, 372, 12), // "modesChanged"
QT_MOC_LITERAL(23, 385, 4), // "mode"
QT_MOC_LITERAL(24, 390, 7), // "ModePtr"
QT_MOC_LITERAL(25, 398, 2), // "id"
QT_MOC_LITERAL(26, 401, 11), // "currentMode"
QT_MOC_LITERAL(27, 413, 15), // "preferredModeId"
QT_MOC_LITERAL(28, 429, 13), // "preferredMode"
QT_MOC_LITERAL(29, 443, 12), // "isHorizontal"
QT_MOC_LITERAL(30, 456, 4), // "name"
QT_MOC_LITERAL(31, 461, 4), // "type"
QT_MOC_LITERAL(32, 466, 4), // "Type"
QT_MOC_LITERAL(33, 471, 4), // "icon"
QT_MOC_LITERAL(34, 476, 5), // "modes"
QT_MOC_LITERAL(35, 482, 8), // "ModeList"
QT_MOC_LITERAL(36, 491, 3), // "pos"
QT_MOC_LITERAL(37, 495, 4), // "size"
QT_MOC_LITERAL(38, 500, 8), // "rotation"
QT_MOC_LITERAL(39, 509, 8), // "Rotation"
QT_MOC_LITERAL(40, 518, 13), // "currentModeId"
QT_MOC_LITERAL(41, 532, 9), // "connected"
QT_MOC_LITERAL(42, 542, 7), // "enabled"
QT_MOC_LITERAL(43, 550, 7), // "primary"
QT_MOC_LITERAL(44, 558, 8), // "priority"
QT_MOC_LITERAL(45, 567, 8), // "uint32_t"
QT_MOC_LITERAL(46, 576, 6), // "clones"
QT_MOC_LITERAL(47, 583, 10), // "QList<int>"
QT_MOC_LITERAL(48, 594, 17), // "replicationSource"
QT_MOC_LITERAL(49, 612, 4), // "edid"
QT_MOC_LITERAL(50, 617, 14), // "KScreen::Edid*"
QT_MOC_LITERAL(51, 632, 6), // "sizeMm"
QT_MOC_LITERAL(52, 639, 5), // "scale"
QT_MOC_LITERAL(53, 645, 19), // "explicitLogicalSize"
QT_MOC_LITERAL(54, 665, 12), // "capabilities"
QT_MOC_LITERAL(55, 678, 12), // "Capabilities"
QT_MOC_LITERAL(56, 691, 8), // "overscan"
QT_MOC_LITERAL(57, 700, 9), // "vrrPolicy"
QT_MOC_LITERAL(58, 710, 9), // "VrrPolicy"
QT_MOC_LITERAL(59, 720, 8), // "rgbRange"
QT_MOC_LITERAL(60, 729, 8), // "RgbRange"
QT_MOC_LITERAL(61, 738, 7), // "Unknown"
QT_MOC_LITERAL(62, 746, 3), // "VGA"
QT_MOC_LITERAL(63, 750, 3), // "DVI"
QT_MOC_LITERAL(64, 754, 4), // "DVII"
QT_MOC_LITERAL(65, 759, 4), // "DVIA"
QT_MOC_LITERAL(66, 764, 4), // "DVID"
QT_MOC_LITERAL(67, 769, 4), // "HDMI"
QT_MOC_LITERAL(68, 774, 5), // "Panel"
QT_MOC_LITERAL(69, 780, 2), // "TV"
QT_MOC_LITERAL(70, 783, 11), // "TVComposite"
QT_MOC_LITERAL(71, 795, 8), // "TVSVideo"
QT_MOC_LITERAL(72, 804, 11), // "TVComponent"
QT_MOC_LITERAL(73, 816, 7), // "TVSCART"
QT_MOC_LITERAL(74, 824, 4), // "TVC4"
QT_MOC_LITERAL(75, 829, 11), // "DisplayPort"
QT_MOC_LITERAL(76, 841, 4), // "None"
QT_MOC_LITERAL(77, 846, 4), // "Left"
QT_MOC_LITERAL(78, 851, 8), // "Inverted"
QT_MOC_LITERAL(79, 860, 5), // "Right"
QT_MOC_LITERAL(80, 866, 10), // "Capability"
QT_MOC_LITERAL(81, 877, 8), // "Overscan"
QT_MOC_LITERAL(82, 886, 3), // "Vrr"
QT_MOC_LITERAL(83, 890, 5), // "Never"
QT_MOC_LITERAL(84, 896, 6), // "Always"
QT_MOC_LITERAL(85, 903, 9), // "Automatic"
QT_MOC_LITERAL(86, 913, 4), // "Full"
QT_MOC_LITERAL(87, 918, 7) // "Limited"

    },
    "KScreen::Output\0RegisterEnumClassesUnscoped\0"
    "false\0outputChanged\0\0posChanged\0"
    "sizeChanged\0currentModeIdChanged\0"
    "rotationChanged\0isConnectedChanged\0"
    "isEnabledChanged\0priorityChanged\0"
    "clonesChanged\0replicationSourceChanged\0"
    "scaleChanged\0explicitLogicalSizeChanged\0"
    "followPreferredModeChanged\0"
    "followPreferredMode\0capabilitiesChanged\0"
    "overscanChanged\0vrrPolicyChanged\0"
    "rgbRangeChanged\0modesChanged\0mode\0"
    "ModePtr\0id\0currentMode\0preferredModeId\0"
    "preferredMode\0isHorizontal\0name\0type\0"
    "Type\0icon\0modes\0ModeList\0pos\0size\0"
    "rotation\0Rotation\0currentModeId\0"
    "connected\0enabled\0primary\0priority\0"
    "uint32_t\0clones\0QList<int>\0replicationSource\0"
    "edid\0KScreen::Edid*\0sizeMm\0scale\0"
    "explicitLogicalSize\0capabilities\0"
    "Capabilities\0overscan\0vrrPolicy\0"
    "VrrPolicy\0rgbRange\0RgbRange\0Unknown\0"
    "VGA\0DVI\0DVII\0DVIA\0DVID\0HDMI\0Panel\0TV\0"
    "TVComposite\0TVSVideo\0TVComponent\0"
    "TVSCART\0TVC4\0DisplayPort\0None\0Left\0"
    "Inverted\0Right\0Capability\0Overscan\0"
    "Vrr\0Never\0Always\0Automatic\0Full\0Limited"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__Output[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      23,   16, // methods
      25,  158, // properties
       6,  258, // enums/sets
       0,    0, // constructors
       0,       // flags
      18,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    0,  131,    4, 0x06 /* Public */,
       5,    0,  132,    4, 0x06 /* Public */,
       6,    0,  133,    4, 0x06 /* Public */,
       7,    0,  134,    4, 0x06 /* Public */,
       8,    0,  135,    4, 0x06 /* Public */,
       9,    0,  136,    4, 0x06 /* Public */,
      10,    0,  137,    4, 0x06 /* Public */,
      11,    0,  138,    4, 0x06 /* Public */,
      12,    0,  139,    4, 0x06 /* Public */,
      13,    0,  140,    4, 0x06 /* Public */,
      14,    0,  141,    4, 0x06 /* Public */,
      15,    0,  142,    4, 0x06 /* Public */,
      16,    1,  143,    4, 0x06 /* Public */,
      18,    0,  146,    4, 0x06 /* Public */,
      19,    0,  147,    4, 0x06 /* Public */,
      20,    0,  148,    4, 0x06 /* Public */,
      21,    0,  149,    4, 0x06 /* Public */,
      22,    0,  150,    4, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      23,    1,  151,    4, 0x02 /* Public */,
      26,    0,  154,    4, 0x02 /* Public */,
      27,    0,  155,    4, 0x02 /* Public */,
      28,    0,  156,    4, 0x02 /* Public */,
      29,    0,  157,    4, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    0x80000000 | 24, QMetaType::QString,   25,
    0x80000000 | 24,
    QMetaType::QString,
    0x80000000 | 24,
    QMetaType::Bool,

 // properties: name, type, flags
      25, QMetaType::Int, 0x00095401,
      30, QMetaType::QString, 0x00495103,
      31, 0x80000000 | 32, 0x0049510b,
      33, QMetaType::QString, 0x00495103,
      34, 0x80000000 | 35, 0x00495009,
      36, QMetaType::QPoint, 0x00495103,
      37, QMetaType::QSize, 0x00495103,
      38, 0x80000000 | 39, 0x0049510b,
      40, QMetaType::QString, 0x00495103,
      27, QMetaType::QString, 0x00095401,
      41, QMetaType::Bool, 0x00495103,
      42, QMetaType::Bool, 0x00495103,
      43, QMetaType::Bool, 0x00495103,
      44, 0x80000000 | 45, 0x0049510b,
      46, 0x80000000 | 47, 0x0049510b,
      48, QMetaType::Int, 0x00495103,
      49, 0x80000000 | 50, 0x00095409,
      51, QMetaType::QSize, 0x00095401,
      52, QMetaType::QReal, 0x00495103,
      17, QMetaType::Bool, 0x00495103,
      53, QMetaType::QSizeF, 0x00495103,
      54, 0x80000000 | 55, 0x00495009,
      56, 0x80000000 | 45, 0x0049510b,
      57, 0x80000000 | 58, 0x0049510b,
      59, 0x80000000 | 60, 0x0049510b,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
      17,
       1,
       2,
       4,
       3,
       0,
       5,
       6,
       7,
       7,
       8,
       9,
       0,
       0,
      10,
      12,
      11,
      13,
      14,
      15,
      16,

 // enums: name, alias, flags, count, data
      32,   32, 0x0,   15,  288,
      39,   39, 0x0,    4,  318,
      80,   80, 0x2,    3,  326,
      55,   80, 0x3,    3,  332,
      58,   58, 0x2,    3,  338,
      60,   60, 0x2,    3,  344,

 // enum data: key, value
      61, uint(KScreen::Output::Unknown),
      62, uint(KScreen::Output::VGA),
      63, uint(KScreen::Output::DVI),
      64, uint(KScreen::Output::DVII),
      65, uint(KScreen::Output::DVIA),
      66, uint(KScreen::Output::DVID),
      67, uint(KScreen::Output::HDMI),
      68, uint(KScreen::Output::Panel),
      69, uint(KScreen::Output::TV),
      70, uint(KScreen::Output::TVComposite),
      71, uint(KScreen::Output::TVSVideo),
      72, uint(KScreen::Output::TVComponent),
      73, uint(KScreen::Output::TVSCART),
      74, uint(KScreen::Output::TVC4),
      75, uint(KScreen::Output::DisplayPort),
      76, uint(KScreen::Output::None),
      77, uint(KScreen::Output::Left),
      78, uint(KScreen::Output::Inverted),
      79, uint(KScreen::Output::Right),
      81, uint(KScreen::Output::Capability::Overscan),
      82, uint(KScreen::Output::Capability::Vrr),
      60, uint(KScreen::Output::Capability::RgbRange),
      81, uint(KScreen::Output::Capability::Overscan),
      82, uint(KScreen::Output::Capability::Vrr),
      60, uint(KScreen::Output::Capability::RgbRange),
      83, uint(KScreen::Output::VrrPolicy::Never),
      84, uint(KScreen::Output::VrrPolicy::Always),
      85, uint(KScreen::Output::VrrPolicy::Automatic),
      85, uint(KScreen::Output::RgbRange::Automatic),
      86, uint(KScreen::Output::RgbRange::Full),
      87, uint(KScreen::Output::RgbRange::Limited),

       0        // eod
};

void KScreen::Output::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Output *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->outputChanged(); break;
        case 1: _t->posChanged(); break;
        case 2: _t->sizeChanged(); break;
        case 3: _t->currentModeIdChanged(); break;
        case 4: _t->rotationChanged(); break;
        case 5: _t->isConnectedChanged(); break;
        case 6: _t->isEnabledChanged(); break;
        case 7: _t->priorityChanged(); break;
        case 8: _t->clonesChanged(); break;
        case 9: _t->replicationSourceChanged(); break;
        case 10: _t->scaleChanged(); break;
        case 11: _t->explicitLogicalSizeChanged(); break;
        case 12: _t->followPreferredModeChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->capabilitiesChanged(); break;
        case 14: _t->overscanChanged(); break;
        case 15: _t->vrrPolicyChanged(); break;
        case 16: _t->rgbRangeChanged(); break;
        case 17: _t->modesChanged(); break;
        case 18: { ModePtr _r = _t->mode((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 19: { ModePtr _r = _t->currentMode();
            if (_a[0]) *reinterpret_cast< ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->preferredModeId();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 21: { ModePtr _r = _t->preferredMode();
            if (_a[0]) *reinterpret_cast< ModePtr*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->isHorizontal();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::outputChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::posChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::sizeChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::currentModeIdChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::rotationChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::isConnectedChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::isEnabledChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::priorityChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::clonesChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::replicationSourceChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::scaleChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::explicitLogicalSizeChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Output::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::followPreferredModeChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::capabilitiesChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::overscanChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::vrrPolicyChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::rgbRangeChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Output::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Output::modesChanged)) {
                *result = 17;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Output *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< int*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< Type*>(_v) = _t->type(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->icon(); break;
        case 4: *reinterpret_cast< ModeList*>(_v) = _t->modes(); break;
        case 5: *reinterpret_cast< QPoint*>(_v) = _t->pos(); break;
        case 6: *reinterpret_cast< QSize*>(_v) = _t->size(); break;
        case 7: *reinterpret_cast< Rotation*>(_v) = _t->rotation(); break;
        case 8: *reinterpret_cast< QString*>(_v) = _t->currentModeId(); break;
        case 9: *reinterpret_cast< QString*>(_v) = _t->preferredModeId(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->isConnected(); break;
        case 11: *reinterpret_cast< bool*>(_v) = _t->isEnabled(); break;
        case 12: *reinterpret_cast< bool*>(_v) = _t->isPrimary(); break;
        case 13: *reinterpret_cast< uint32_t*>(_v) = _t->priority(); break;
        case 14: *reinterpret_cast< QList<int>*>(_v) = _t->clones(); break;
        case 15: *reinterpret_cast< int*>(_v) = _t->replicationSource(); break;
        case 16: *reinterpret_cast< KScreen::Edid**>(_v) = _t->edid(); break;
        case 17: *reinterpret_cast< QSize*>(_v) = _t->sizeMm(); break;
        case 18: *reinterpret_cast< qreal*>(_v) = _t->scale(); break;
        case 19: *reinterpret_cast< bool*>(_v) = _t->followPreferredMode(); break;
        case 20: *reinterpret_cast< QSizeF*>(_v) = _t->explicitLogicalSize(); break;
        case 21: *reinterpret_cast<int*>(_v) = QFlag(_t->capabilities()); break;
        case 22: *reinterpret_cast< uint32_t*>(_v) = _t->overscan(); break;
        case 23: *reinterpret_cast< VrrPolicy*>(_v) = _t->vrrPolicy(); break;
        case 24: *reinterpret_cast< RgbRange*>(_v) = _t->rgbRange(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<Output *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setName(*reinterpret_cast< QString*>(_v)); break;
        case 2: _t->setType(*reinterpret_cast< Type*>(_v)); break;
        case 3: _t->setIcon(*reinterpret_cast< QString*>(_v)); break;
        case 5: _t->setPos(*reinterpret_cast< QPoint*>(_v)); break;
        case 6: _t->setSize(*reinterpret_cast< QSize*>(_v)); break;
        case 7: _t->setRotation(*reinterpret_cast< Rotation*>(_v)); break;
        case 8: _t->setCurrentModeId(*reinterpret_cast< QString*>(_v)); break;
        case 10: _t->setConnected(*reinterpret_cast< bool*>(_v)); break;
        case 11: _t->setEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 12: _t->setPrimary(*reinterpret_cast< bool*>(_v)); break;
        case 13: _t->setPriority(*reinterpret_cast< uint32_t*>(_v)); break;
        case 14: _t->setClones(*reinterpret_cast< QList<int>*>(_v)); break;
        case 15: _t->setReplicationSource(*reinterpret_cast< int*>(_v)); break;
        case 18: _t->setScale(*reinterpret_cast< qreal*>(_v)); break;
        case 19: _t->setFollowPreferredMode(*reinterpret_cast< bool*>(_v)); break;
        case 20: _t->setExplicitLogicalSize(*reinterpret_cast< QSizeF*>(_v)); break;
        case 22: _t->setOverscan(*reinterpret_cast< uint32_t*>(_v)); break;
        case 23: _t->setVrrPolicy(*reinterpret_cast< VrrPolicy*>(_v)); break;
        case 24: _t->setRgbRange(*reinterpret_cast< RgbRange*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KScreen::Output::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__Output.data,
    qt_meta_data_KScreen__Output,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::Output::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Output::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__Output.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Output::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 23;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 25;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 25;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 25;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 25;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 25;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KScreen::Output::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KScreen::Output::posChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KScreen::Output::sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KScreen::Output::currentModeIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KScreen::Output::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KScreen::Output::isConnectedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KScreen::Output::isEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KScreen::Output::priorityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KScreen::Output::clonesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KScreen::Output::replicationSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KScreen::Output::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KScreen::Output::explicitLogicalSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KScreen::Output::followPreferredModeChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void KScreen::Output::capabilitiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KScreen::Output::overscanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KScreen::Output::vrrPolicyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KScreen::Output::rgbRangeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KScreen::Output::modesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
