// This file is autogenerated. Changes will be overwritten.
#include "6BFSOG4JBM/moc_xcbeventlistener.cpp"
#include "EWIEGA46WW/moc_xrandr.cpp"
#include "EWIEGA46WW/moc_xrandrconfig.cpp"
#include "EWIEGA46WW/moc_xrandrcrtc.cpp"
#include "EWIEGA46WW/moc_xrandrmode.cpp"
#include "EWIEGA46WW/moc_xrandroutput.cpp"
#include "EWIEGA46WW/moc_xrandrscreen.cpp"
