/****************************************************************************
** Meta object code from reading C++ file 'edid.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../libkscreen-5.27.12/src/edid.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'edid.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KScreen__Edid_t {
    QByteArrayData data[14];
    char stringdata0[94];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__Edid_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__Edid_t qt_meta_stringdata_KScreen__Edid = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KScreen::Edid"
QT_MOC_LITERAL(1, 14, 8), // "deviceId"
QT_MOC_LITERAL(2, 23, 4), // "name"
QT_MOC_LITERAL(3, 28, 6), // "vendor"
QT_MOC_LITERAL(4, 35, 6), // "serial"
QT_MOC_LITERAL(5, 42, 6), // "eisaId"
QT_MOC_LITERAL(6, 49, 4), // "hash"
QT_MOC_LITERAL(7, 54, 5), // "width"
QT_MOC_LITERAL(8, 60, 6), // "height"
QT_MOC_LITERAL(9, 67, 5), // "gamma"
QT_MOC_LITERAL(10, 73, 3), // "red"
QT_MOC_LITERAL(11, 77, 5), // "green"
QT_MOC_LITERAL(12, 83, 4), // "blue"
QT_MOC_LITERAL(13, 88, 5) // "white"

    },
    "KScreen::Edid\0deviceId\0name\0vendor\0"
    "serial\0eisaId\0hash\0width\0height\0gamma\0"
    "red\0green\0blue\0white"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__Edid[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
      13,   14, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095401,
       2, QMetaType::QString, 0x00095401,
       3, QMetaType::QString, 0x00095401,
       4, QMetaType::QString, 0x00095401,
       5, QMetaType::QString, 0x00095401,
       6, QMetaType::QString, 0x00095401,
       7, QMetaType::UInt, 0x00095401,
       8, QMetaType::UInt, 0x00095401,
       9, QMetaType::QReal, 0x00095401,
      10, QMetaType::QQuaternion, 0x00095401,
      11, QMetaType::QQuaternion, 0x00095401,
      12, QMetaType::QQuaternion, 0x00095401,
      13, QMetaType::QQuaternion, 0x00095401,

       0        // eod
};

void KScreen::Edid::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Edid *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->deviceId(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->vendor(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->serial(); break;
        case 4: *reinterpret_cast< QString*>(_v) = _t->eisaId(); break;
        case 5: *reinterpret_cast< QString*>(_v) = _t->hash(); break;
        case 6: *reinterpret_cast< uint*>(_v) = _t->width(); break;
        case 7: *reinterpret_cast< uint*>(_v) = _t->height(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->gamma(); break;
        case 9: *reinterpret_cast< QQuaternion*>(_v) = _t->red(); break;
        case 10: *reinterpret_cast< QQuaternion*>(_v) = _t->green(); break;
        case 11: *reinterpret_cast< QQuaternion*>(_v) = _t->blue(); break;
        case 12: *reinterpret_cast< QQuaternion*>(_v) = _t->white(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KScreen::Edid::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__Edid.data,
    qt_meta_data_KScreen__Edid,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::Edid::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Edid::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__Edid.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Edid::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    
#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 13;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 13;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
