/****************************************************************************
** Meta object code from reading C++ file 'waylandoutputmanagement.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../libkscreen-5.27.12/backends/kwayland/waylandoutputmanagement.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'waylandoutputmanagement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KScreen__WaylandOutputConfiguration_t {
    QByteArrayData data[4];
    char stringdata0[52];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__WaylandOutputConfiguration_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__WaylandOutputConfiguration_t qt_meta_stringdata_KScreen__WaylandOutputConfiguration = {
    {
QT_MOC_LITERAL(0, 0, 35), // "KScreen::WaylandOutputConfigu..."
QT_MOC_LITERAL(1, 36, 7), // "applied"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 6) // "failed"

    },
    "KScreen::WaylandOutputConfiguration\0"
    "applied\0\0failed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__WaylandOutputConfiguration[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x06 /* Public */,
       3,    0,   25,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KScreen::WaylandOutputConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WaylandOutputConfiguration *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->applied(); break;
        case 1: _t->failed(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WaylandOutputConfiguration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaylandOutputConfiguration::applied)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (WaylandOutputConfiguration::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaylandOutputConfiguration::failed)) {
                *result = 1;
                return;
            }
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KScreen::WaylandOutputConfiguration::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__WaylandOutputConfiguration.data,
    qt_meta_data_KScreen__WaylandOutputConfiguration,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::WaylandOutputConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::WaylandOutputConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__WaylandOutputConfiguration.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::kde_output_configuration_v2"))
        return static_cast< QtWayland::kde_output_configuration_v2*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::WaylandOutputConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KScreen::WaylandOutputConfiguration::applied()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KScreen::WaylandOutputConfiguration::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
struct qt_meta_stringdata_KScreen__WaylandOutputManagement_t {
    QByteArrayData data[1];
    char stringdata0[33];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__WaylandOutputManagement_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__WaylandOutputManagement_t qt_meta_stringdata_KScreen__WaylandOutputManagement = {
    {
QT_MOC_LITERAL(0, 0, 32) // "KScreen::WaylandOutputManagement"

    },
    "KScreen::WaylandOutputManagement"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__WaylandOutputManagement[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void KScreen::WaylandOutputManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KScreen::WaylandOutputManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__WaylandOutputManagement.data,
    qt_meta_data_KScreen__WaylandOutputManagement,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::WaylandOutputManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::WaylandOutputManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__WaylandOutputManagement.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::kde_output_management_v2"))
        return static_cast< QtWayland::kde_output_management_v2*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::WaylandOutputManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_KScreen__WaylandOutputOrder_t {
    QByteArrayData data[5];
    char stringdata0[73];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__WaylandOutputOrder_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__WaylandOutputOrder_t qt_meta_stringdata_KScreen__WaylandOutputOrder = {
    {
QT_MOC_LITERAL(0, 0, 27), // "KScreen::WaylandOutputOrder"
QT_MOC_LITERAL(1, 28, 18), // "outputOrderChanged"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 16), // "QVector<QString>"
QT_MOC_LITERAL(4, 65, 7) // "outputs"

    },
    "KScreen::WaylandOutputOrder\0"
    "outputOrderChanged\0\0QVector<QString>\0"
    "outputs"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__WaylandOutputOrder[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KScreen::WaylandOutputOrder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<WaylandOutputOrder *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->outputOrderChanged((*reinterpret_cast< const QVector<QString>(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QVector<QString> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (WaylandOutputOrder::*)(const QVector<QString> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WaylandOutputOrder::outputOrderChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KScreen::WaylandOutputOrder::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__WaylandOutputOrder.data,
    qt_meta_data_KScreen__WaylandOutputOrder,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::WaylandOutputOrder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::WaylandOutputOrder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__WaylandOutputOrder.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::kde_output_order_v1"))
        return static_cast< QtWayland::kde_output_order_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::WaylandOutputOrder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KScreen::WaylandOutputOrder::outputOrderChanged(const QVector<QString> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
