/* Generated by wayland-scanner 1.25.0 */

/*
 * SPDX-FileCopyrightText: 2008-2011 Kristian Høgsberg
 * SPDX-FileCopyrightText: 2010-2011 Intel Corporation
 * SPDX-FileCopyrightText: 2012-2013 Collabora, Ltd.
 * SPDX-FileCopyrightText: 2015 Sebastian Kügler <sebas@kde.org>
 * SPDX-FileCopyrightText: 2021 Méven Car <meven.car@enioka.com>
 * SPDX-FileCopyrightText: 2023 Xaver Hugl <xaver.hugl@kde.org>
 *
 * SPDX-License-Identifier: MIT-CMU
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface kde_mode_list_v2_interface;
extern const struct wl_interface kde_output_configuration_v2_interface;
extern const struct wl_interface kde_output_device_mode_v2_interface;
extern const struct wl_interface kde_output_device_v2_interface;

static const struct wl_interface *kde_output_management_v2_types[] = {
	NULL,
	NULL,
	&kde_output_configuration_v2_interface,
	&kde_mode_list_v2_interface,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	&kde_output_device_mode_v2_interface,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	NULL,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	&kde_mode_list_v2_interface,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
	&kde_output_device_v2_interface,
	NULL,
};

static const struct wl_message kde_output_management_v2_requests[] = {
	{ "create_configuration", "n", kde_output_management_v2_types + 2 },
	{ "create_mode_list", "n", kde_output_management_v2_types + 3 },
};

WL_EXPORT const struct wl_interface kde_output_management_v2_interface = {
	"kde_output_management_v2", 21,
	2, kde_output_management_v2_requests,
	0, NULL,
};

static const struct wl_message kde_output_configuration_v2_requests[] = {
	{ "enable", "oi", kde_output_management_v2_types + 4 },
	{ "mode", "oo", kde_output_management_v2_types + 6 },
	{ "transform", "oi", kde_output_management_v2_types + 8 },
	{ "position", "oii", kde_output_management_v2_types + 10 },
	{ "scale", "of", kde_output_management_v2_types + 13 },
	{ "apply", "", kde_output_management_v2_types + 0 },
	{ "destroy", "", kde_output_management_v2_types + 0 },
	{ "overscan", "ou", kde_output_management_v2_types + 15 },
	{ "set_vrr_policy", "ou", kde_output_management_v2_types + 17 },
	{ "set_rgb_range", "ou", kde_output_management_v2_types + 19 },
	{ "set_primary_output", "2o", kde_output_management_v2_types + 21 },
	{ "set_priority", "3ou", kde_output_management_v2_types + 22 },
	{ "set_high_dynamic_range", "4ou", kde_output_management_v2_types + 24 },
	{ "set_sdr_brightness", "4ou", kde_output_management_v2_types + 26 },
	{ "set_wide_color_gamut", "4ou", kde_output_management_v2_types + 28 },
	{ "set_auto_rotate_policy", "5ou", kde_output_management_v2_types + 30 },
	{ "set_icc_profile_path", "6os", kde_output_management_v2_types + 32 },
	{ "set_brightness_overrides", "7oiii", kde_output_management_v2_types + 34 },
	{ "set_sdr_gamut_wideness", "7ou", kde_output_management_v2_types + 38 },
	{ "set_color_profile_source", "8ou", kde_output_management_v2_types + 40 },
	{ "set_brightness", "9ou", kde_output_management_v2_types + 42 },
	{ "set_color_power_tradeoff", "10ou", kde_output_management_v2_types + 44 },
	{ "set_dimming", "11ou", kde_output_management_v2_types + 46 },
	{ "set_replication_source", "13os", kde_output_management_v2_types + 48 },
	{ "set_ddc_ci_allowed", "14ou", kde_output_management_v2_types + 50 },
	{ "set_max_bits_per_color", "15ou", kde_output_management_v2_types + 52 },
	{ "set_edr_policy", "16ou", kde_output_management_v2_types + 54 },
	{ "set_sharpness", "17ou", kde_output_management_v2_types + 56 },
	{ "set_custom_modes", "18oo", kde_output_management_v2_types + 58 },
	{ "set_auto_brightness", "19ou", kde_output_management_v2_types + 60 },
	{ "set_hdr_icc_profile_path", "20os", kde_output_management_v2_types + 62 },
	{ "set_hdr_color_profile_source", "20ou", kde_output_management_v2_types + 64 },
	{ "set_abm_level", "21ou", kde_output_management_v2_types + 66 },
};

static const struct wl_message kde_output_configuration_v2_events[] = {
	{ "applied", "", kde_output_management_v2_types + 0 },
	{ "failed", "", kde_output_management_v2_types + 0 },
	{ "failure_reason", "12s", kde_output_management_v2_types + 0 },
};

WL_EXPORT const struct wl_interface kde_output_configuration_v2_interface = {
	"kde_output_configuration_v2", 21,
	33, kde_output_configuration_v2_requests,
	3, kde_output_configuration_v2_events,
};

static const struct wl_message kde_mode_list_v2_requests[] = {
	{ "destroy", "", kde_output_management_v2_types + 0 },
	{ "add_mode", "", kde_output_management_v2_types + 0 },
	{ "set_resolution", "uu", kde_output_management_v2_types + 0 },
	{ "set_refresh_rate", "u", kde_output_management_v2_types + 0 },
	{ "set_reduced_blanking", "u", kde_output_management_v2_types + 0 },
};

WL_EXPORT const struct wl_interface kde_mode_list_v2_interface = {
	"kde_mode_list_v2", 20,
	5, kde_mode_list_v2_requests,
	0, NULL,
};

