// This file was generated by qtwaylandscanner
// source file is /usr/share/plasma-wayland-protocols/kde-output-device-v2.xml

#ifndef QT_WAYLAND_KDE_OUTPUT_DEVICE_V2
#define QT_WAYLAND_KDE_OUTPUT_DEVICE_V2

#include "wayland-kde-output-device-v2-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")

namespace QtWayland {
    class  kde_output_device_registry_v2
    {
    public:
        kde_output_device_registry_v2(struct ::wl_registry *registry, int id, int version);
        kde_output_device_registry_v2(struct ::kde_output_device_registry_v2 *object);
        kde_output_device_registry_v2();

        virtual ~kde_output_device_registry_v2();

        void init(struct ::wl_registry *registry, int id, int version);
        void init(struct ::kde_output_device_registry_v2 *object);

        struct ::kde_output_device_registry_v2 *object() { return m_kde_output_device_registry_v2; }
        const struct ::kde_output_device_registry_v2 *object() const { return m_kde_output_device_registry_v2; }
        static kde_output_device_registry_v2 *fromObject(struct ::kde_output_device_registry_v2 *object);

        bool isInitialized() const;

        static const struct ::wl_interface *interface();

        enum error {
            error_unsupported_version = 0, // the registry was bound with an unsupported version
        };

        void stop();

    protected:
        virtual void kde_output_device_registry_v2_finished();
        virtual void kde_output_device_registry_v2_output(struct ::kde_output_device_v2 *output);

    private:
        void init_listener();
        static const struct kde_output_device_registry_v2_listener m_kde_output_device_registry_v2_listener;
        static void handle_finished(
            void *data,
            struct ::kde_output_device_registry_v2 *object);
        static void handle_output(
            void *data,
            struct ::kde_output_device_registry_v2 *object,
            struct ::kde_output_device_v2 *output);
        struct ::kde_output_device_registry_v2 *m_kde_output_device_registry_v2;
    };

    class  kde_output_device_v2
    {
    public:
        kde_output_device_v2(struct ::wl_registry *registry, int id, int version);
        kde_output_device_v2(struct ::kde_output_device_v2 *object);
        kde_output_device_v2();

        virtual ~kde_output_device_v2();

        void init(struct ::wl_registry *registry, int id, int version);
        void init(struct ::kde_output_device_v2 *object);

        struct ::kde_output_device_v2 *object() { return m_kde_output_device_v2; }
        const struct ::kde_output_device_v2 *object() const { return m_kde_output_device_v2; }
        static kde_output_device_v2 *fromObject(struct ::kde_output_device_v2 *object);

        bool isInitialized() const;

        static const struct ::wl_interface *interface();

        enum subpixel {
            subpixel_unknown = 0,
            subpixel_none = 1,
            subpixel_horizontal_rgb = 2,
            subpixel_horizontal_bgr = 3,
            subpixel_vertical_rgb = 4,
            subpixel_vertical_bgr = 5,
        };

        enum transform {
            transform_normal = 0,
            transform_90 = 1,
            transform_180 = 2,
            transform_270 = 3,
            transform_flipped = 4,
            transform_flipped_90 = 5,
            transform_flipped_180 = 6,
            transform_flipped_270 = 7,
        };

        enum capability {
            capability_overscan = 0x1, // if this output_device can use overscan
            capability_vrr = 0x2, // if this outputdevice supports variable refresh rate
            capability_rgb_range = 0x4, // if setting the rgb range is possible
            capability_high_dynamic_range = 0x8, // if this outputdevice supports high dynamic range
            capability_wide_color_gamut = 0x10, // if this outputdevice supports a wide color gamut
            capability_auto_rotate = 0x20, // if this outputdevice supports autorotation
            capability_icc_profile = 0x40, // if this outputdevice supports icc profiles
            capability_brightness = 0x80, // if this outputdevice supports the brightness setting
            capability_built_in_color = 0x100, // if this outputdevice supports the built-in color profile
            capability_ddc_ci = 0x200, // if this outputdevice supports DDC/CI
            capability_max_bits_per_color = 0x400, // if this outputdevice supports setting max bpc
            capability_edr = 0x800, // if this outputdevice supports EDR
            capability_sharpness = 0x1000, // if this outputdevice supports the sharpness setting
            capability_custom_modes = 0x2000, // if this outputdevice supports custom modes
            capability_auto_brightness = 0x4000,
            capability_hdr_icc_profile = 0x8000, // if this outputdevice supports HDR ICC profiles
            capability_abm_level = 0x10000, // if this outputdevice supports the abm level setting
        };

        enum vrr_policy {
            vrr_policy_never = 0,
            vrr_policy_always = 1,
            vrr_policy_automatic = 2,
        };

        enum rgb_range {
            rgb_range_automatic = 0,
            rgb_range_full = 1,
            rgb_range_limited = 2,
        };

        enum auto_rotate_policy {
            auto_rotate_policy_never = 0,
            auto_rotate_policy_in_tablet_mode = 1,
            auto_rotate_policy_always = 2,
        };

        enum color_profile_source {
            color_profile_source_sRGB = 0,
            color_profile_source_ICC = 1,
            color_profile_source_EDID = 2,
        };

        enum color_power_tradeoff {
            color_power_tradeoff_efficiency = 0, // prefer efficiency and performance
            color_power_tradeoff_accuracy = 1, // prefer accuracy
        };

        enum edr_policy {
            edr_policy_never = 0,
            edr_policy_always = 1,
        };

        void release();

    protected:
        virtual void kde_output_device_v2_geometry(int32_t x, int32_t y, int32_t physical_width, int32_t physical_height, int32_t subpixel, const QString &make, const QString &model, int32_t transform);
        virtual void kde_output_device_v2_current_mode(struct ::kde_output_device_mode_v2 *mode);
        virtual void kde_output_device_v2_mode(struct ::kde_output_device_mode_v2 *mode);
        virtual void kde_output_device_v2_done();
        virtual void kde_output_device_v2_scale(wl_fixed_t factor);
        virtual void kde_output_device_v2_edid(const QString &raw);
        virtual void kde_output_device_v2_enabled(int32_t enabled);
        virtual void kde_output_device_v2_uuid(const QString &uuid);
        virtual void kde_output_device_v2_serial_number(const QString &serialNumber);
        virtual void kde_output_device_v2_eisa_id(const QString &eisaId);
        virtual void kde_output_device_v2_capabilities(uint32_t flags);
        virtual void kde_output_device_v2_overscan(uint32_t overscan);
        virtual void kde_output_device_v2_vrr_policy(uint32_t vrr_policy);
        virtual void kde_output_device_v2_rgb_range(uint32_t rgb_range);
        virtual void kde_output_device_v2_name(const QString &name);
        virtual void kde_output_device_v2_high_dynamic_range(uint32_t hdr_enabled);
        virtual void kde_output_device_v2_sdr_brightness(uint32_t sdr_brightness);
        virtual void kde_output_device_v2_wide_color_gamut(uint32_t wcg_enabled);
        virtual void kde_output_device_v2_auto_rotate_policy(uint32_t policy);
        virtual void kde_output_device_v2_icc_profile_path(const QString &profile_path);
        virtual void kde_output_device_v2_brightness_metadata(uint32_t max_peak_brightness, uint32_t max_frame_average_brightness, uint32_t min_brightness);
        virtual void kde_output_device_v2_brightness_overrides(int32_t max_peak_brightness, int32_t max_average_brightness, int32_t min_brightness);
        virtual void kde_output_device_v2_sdr_gamut_wideness(uint32_t gamut_wideness);
        virtual void kde_output_device_v2_color_profile_source(uint32_t source);
        virtual void kde_output_device_v2_brightness(uint32_t brightness);
        virtual void kde_output_device_v2_color_power_tradeoff(uint32_t preference);
        virtual void kde_output_device_v2_dimming(uint32_t multiplier);
        virtual void kde_output_device_v2_replication_source(const QString &source);
        virtual void kde_output_device_v2_ddc_ci_allowed(uint32_t allowed);
        virtual void kde_output_device_v2_max_bits_per_color(uint32_t max_bpc);
        virtual void kde_output_device_v2_max_bits_per_color_range(uint32_t min_value, uint32_t max_value);
        virtual void kde_output_device_v2_automatic_max_bits_per_color_limit(uint32_t max_bpc_limit);
        virtual void kde_output_device_v2_edr_policy(uint32_t policy);
        virtual void kde_output_device_v2_sharpness(uint32_t sharpness);
        virtual void kde_output_device_v2_priority(uint32_t priority);
        virtual void kde_output_device_v2_auto_brightness(uint32_t enabled);
        virtual void kde_output_device_v2_removed();
        virtual void kde_output_device_v2_hdr_icc_profile_path(const QString &profile_path);
        virtual void kde_output_device_v2_hdr_color_profile_source(uint32_t source);
        virtual void kde_output_device_v2_abm_level(uint32_t level);

    private:
        void init_listener();
        static const struct kde_output_device_v2_listener m_kde_output_device_v2_listener;
        static void handle_geometry(
            void *data,
            struct ::kde_output_device_v2 *object,
            int32_t x,
            int32_t y,
            int32_t physical_width,
            int32_t physical_height,
            int32_t subpixel,
            const char *make,
            const char *model,
            int32_t transform);
        static void handle_current_mode(
            void *data,
            struct ::kde_output_device_v2 *object,
            struct ::kde_output_device_mode_v2 *mode);
        static void handle_mode(
            void *data,
            struct ::kde_output_device_v2 *object,
            struct ::kde_output_device_mode_v2 *mode);
        static void handle_done(
            void *data,
            struct ::kde_output_device_v2 *object);
        static void handle_scale(
            void *data,
            struct ::kde_output_device_v2 *object,
            wl_fixed_t factor);
        static void handle_edid(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *raw);
        static void handle_enabled(
            void *data,
            struct ::kde_output_device_v2 *object,
            int32_t enabled);
        static void handle_uuid(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *uuid);
        static void handle_serial_number(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *serialNumber);
        static void handle_eisa_id(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *eisaId);
        static void handle_capabilities(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t flags);
        static void handle_overscan(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t overscan);
        static void handle_vrr_policy(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t vrr_policy);
        static void handle_rgb_range(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t rgb_range);
        static void handle_name(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *name);
        static void handle_high_dynamic_range(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t hdr_enabled);
        static void handle_sdr_brightness(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t sdr_brightness);
        static void handle_wide_color_gamut(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t wcg_enabled);
        static void handle_auto_rotate_policy(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t policy);
        static void handle_icc_profile_path(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *profile_path);
        static void handle_brightness_metadata(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t max_peak_brightness,
            uint32_t max_frame_average_brightness,
            uint32_t min_brightness);
        static void handle_brightness_overrides(
            void *data,
            struct ::kde_output_device_v2 *object,
            int32_t max_peak_brightness,
            int32_t max_average_brightness,
            int32_t min_brightness);
        static void handle_sdr_gamut_wideness(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t gamut_wideness);
        static void handle_color_profile_source(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t source);
        static void handle_brightness(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t brightness);
        static void handle_color_power_tradeoff(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t preference);
        static void handle_dimming(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t multiplier);
        static void handle_replication_source(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *source);
        static void handle_ddc_ci_allowed(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t allowed);
        static void handle_max_bits_per_color(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t max_bpc);
        static void handle_max_bits_per_color_range(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t min_value,
            uint32_t max_value);
        static void handle_automatic_max_bits_per_color_limit(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t max_bpc_limit);
        static void handle_edr_policy(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t policy);
        static void handle_sharpness(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t sharpness);
        static void handle_priority(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t priority);
        static void handle_auto_brightness(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t enabled);
        static void handle_removed(
            void *data,
            struct ::kde_output_device_v2 *object);
        static void handle_hdr_icc_profile_path(
            void *data,
            struct ::kde_output_device_v2 *object,
            const char *profile_path);
        static void handle_hdr_color_profile_source(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t source);
        static void handle_abm_level(
            void *data,
            struct ::kde_output_device_v2 *object,
            uint32_t level);
        struct ::kde_output_device_v2 *m_kde_output_device_v2;
    };

    class  kde_output_device_mode_v2
    {
    public:
        kde_output_device_mode_v2(struct ::wl_registry *registry, int id, int version);
        kde_output_device_mode_v2(struct ::kde_output_device_mode_v2 *object);
        kde_output_device_mode_v2();

        virtual ~kde_output_device_mode_v2();

        void init(struct ::wl_registry *registry, int id, int version);
        void init(struct ::kde_output_device_mode_v2 *object);

        struct ::kde_output_device_mode_v2 *object() { return m_kde_output_device_mode_v2; }
        const struct ::kde_output_device_mode_v2 *object() const { return m_kde_output_device_mode_v2; }
        static kde_output_device_mode_v2 *fromObject(struct ::kde_output_device_mode_v2 *object);

        bool isInitialized() const;

        static const struct ::wl_interface *interface();

        enum flags {
            flags_custom = 0x1,
            flags_reduced_blanking = 0x2,
        };

    protected:
        virtual void kde_output_device_mode_v2_size(int32_t width, int32_t height);
        virtual void kde_output_device_mode_v2_refresh(int32_t refresh);
        virtual void kde_output_device_mode_v2_preferred();
        virtual void kde_output_device_mode_v2_removed();
        virtual void kde_output_device_mode_v2_flags(uint32_t flags);

    private:
        void init_listener();
        static const struct kde_output_device_mode_v2_listener m_kde_output_device_mode_v2_listener;
        static void handle_size(
            void *data,
            struct ::kde_output_device_mode_v2 *object,
            int32_t width,
            int32_t height);
        static void handle_refresh(
            void *data,
            struct ::kde_output_device_mode_v2 *object,
            int32_t refresh);
        static void handle_preferred(
            void *data,
            struct ::kde_output_device_mode_v2 *object);
        static void handle_removed(
            void *data,
            struct ::kde_output_device_mode_v2 *object);
        static void handle_flags(
            void *data,
            struct ::kde_output_device_mode_v2 *object,
            uint32_t flags);
        struct ::kde_output_device_mode_v2 *m_kde_output_device_mode_v2;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
