/****************************************************************************
** Meta object code from reading C++ file 'dpms.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../libkscreen-5.27.12/src/libdpms/dpms.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dpms.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KScreen__Dpms_t {
    QByteArrayData data[19];
    char stringdata0[192];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__Dpms_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__Dpms_t qt_meta_stringdata_KScreen__Dpms = {
    {
QT_MOC_LITERAL(0, 0, 13), // "KScreen::Dpms"
QT_MOC_LITERAL(1, 14, 16), // "supportedChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 9), // "supported"
QT_MOC_LITERAL(4, 42, 11), // "modeChanged"
QT_MOC_LITERAL(5, 54, 4), // "Mode"
QT_MOC_LITERAL(6, 59, 4), // "mode"
QT_MOC_LITERAL(7, 64, 8), // "QScreen*"
QT_MOC_LITERAL(8, 73, 6), // "screen"
QT_MOC_LITERAL(9, 80, 24), // "hasPendingChangesChanged"
QT_MOC_LITERAL(10, 105, 17), // "hasPendingChanges"
QT_MOC_LITERAL(11, 123, 10), // "switchMode"
QT_MOC_LITERAL(12, 134, 15), // "QList<QScreen*>"
QT_MOC_LITERAL(13, 150, 11), // "isSupported"
QT_MOC_LITERAL(14, 162, 2), // "On"
QT_MOC_LITERAL(15, 165, 7), // "Standby"
QT_MOC_LITERAL(16, 173, 7), // "Suspend"
QT_MOC_LITERAL(17, 181, 3), // "Off"
QT_MOC_LITERAL(18, 185, 6) // "Toggle"

    },
    "KScreen::Dpms\0supportedChanged\0\0"
    "supported\0modeChanged\0Mode\0mode\0"
    "QScreen*\0screen\0hasPendingChangesChanged\0"
    "hasPendingChanges\0switchMode\0"
    "QList<QScreen*>\0isSupported\0On\0Standby\0"
    "Suspend\0Off\0Toggle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__Dpms[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       2,   58, // properties
       1,   66, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,
       4,    2,   42,    2, 0x06 /* Public */,
       9,    1,   47,    2, 0x06 /* Public */,

 // methods: name, argc, parameters, tag, flags
      11,    2,   50,    2, 0x42 /* Public | isScriptable */,
      11,    1,   55,    2, 0x62 /* Public | MethodCloned | isScriptable */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 7,    6,    8,
    QMetaType::Void, QMetaType::Bool,   10,

 // methods: parameters
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 12,    6,    8,
    QMetaType::Void, 0x80000000 | 5,    6,

 // properties: name, type, flags
      13, QMetaType::Bool, 0x00495001,
      10, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       0,
       2,

 // enums: name, alias, flags, count, data
       5,    5, 0x0,    5,   71,

 // enum data: key, value
      14, uint(KScreen::Dpms::On),
      15, uint(KScreen::Dpms::Standby),
      16, uint(KScreen::Dpms::Suspend),
      17, uint(KScreen::Dpms::Off),
      18, uint(KScreen::Dpms::Toggle),

       0        // eod
};

void KScreen::Dpms::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Dpms *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->supportedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->modeChanged((*reinterpret_cast< Mode(*)>(_a[1])),(*reinterpret_cast< QScreen*(*)>(_a[2]))); break;
        case 2: _t->hasPendingChangesChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->switchMode((*reinterpret_cast< Mode(*)>(_a[1])),(*reinterpret_cast< const QList<QScreen*>(*)>(_a[2]))); break;
        case 4: _t->switchMode((*reinterpret_cast< Mode(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QScreen* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QScreen*> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Dpms::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Dpms::supportedChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Dpms::*)(Mode , QScreen * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Dpms::modeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Dpms::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Dpms::hasPendingChangesChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Dpms *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isSupported(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->hasPendingChanges(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KScreen::Dpms::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__Dpms.data,
    qt_meta_data_KScreen__Dpms,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::Dpms::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Dpms::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__Dpms.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Dpms::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KScreen::Dpms::supportedChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KScreen::Dpms::modeChanged(Mode _t1, QScreen * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KScreen::Dpms::hasPendingChangesChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
