//
// SPDX-FileCopyrightText: 2015 by Martin Gräßlin <mgraesslin@kde.org>
//
// SPDX-FileCopyrightText: 2022 Aleix Pol Gonzalez <aleixpol@kde.org>
//
// SPDX-License-Identifier: LGPL-2.1-or-later

#include "abstractdpmshelper_p.h"

KScreen::AbstractDpmsHelper::~AbstractDpmsHelper() = default;
