/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p backendinterface /build/libkscreen5/src/libkscreen-5.27.12/interfaces/org.kde.KScreen.Backend.xml
 *
 * qdbusxml2cpp is Copyright (C) 2023 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef BACKENDINTERFACE_H
#define BACKENDINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kscreen.Backend
 */
class OrgKdeKscreenBackendInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kscreen.Backend"; }

public:
    OrgKdeKscreenBackendInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKscreenBackendInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QVariantMap> getConfig()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("getConfig"), argumentList);
    }

    inline QDBusPendingReply<QByteArray> getEdid(int in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("getEdid"), argumentList);
    }

    inline QDBusPendingReply<QVariantMap> setConfig(const QVariantMap &in0)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(in0);
        return asyncCallWithArgumentList(QStringLiteral("setConfig"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void configChanged(const QVariantMap &in0);
};

namespace org {
  namespace kde {
    namespace kscreen {
      typedef ::OrgKdeKscreenBackendInterface Backend;
    }
  }
}
#endif
