/****************************************************************************
** Meta object code from reading C++ file 'config.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../libkscreen-5.27.12/src/config.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KScreen__Config_t {
    QByteArrayData data[24];
    char stringdata0[312];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KScreen__Config_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KScreen__Config_t qt_meta_stringdata_KScreen__Config = {
    {
QT_MOC_LITERAL(0, 0, 15), // "KScreen::Config"
QT_MOC_LITERAL(1, 16, 11), // "outputAdded"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 18), // "KScreen::OutputPtr"
QT_MOC_LITERAL(4, 48, 6), // "output"
QT_MOC_LITERAL(5, 55, 13), // "outputRemoved"
QT_MOC_LITERAL(6, 69, 8), // "outputId"
QT_MOC_LITERAL(7, 78, 17), // "prioritiesChanged"
QT_MOC_LITERAL(8, 96, 6), // "screen"
QT_MOC_LITERAL(9, 103, 9), // "ScreenPtr"
QT_MOC_LITERAL(10, 113, 7), // "outputs"
QT_MOC_LITERAL(11, 121, 10), // "OutputList"
QT_MOC_LITERAL(12, 132, 12), // "ValidityFlag"
QT_MOC_LITERAL(13, 145, 4), // "None"
QT_MOC_LITERAL(14, 150, 30), // "RequireAtLeastOneEnabledScreen"
QT_MOC_LITERAL(15, 181, 7), // "Feature"
QT_MOC_LITERAL(16, 189, 14), // "PrimaryDisplay"
QT_MOC_LITERAL(17, 204, 8), // "Writable"
QT_MOC_LITERAL(18, 213, 16), // "PerOutputScaling"
QT_MOC_LITERAL(19, 230, 17), // "OutputReplication"
QT_MOC_LITERAL(20, 248, 12), // "AutoRotation"
QT_MOC_LITERAL(21, 261, 10), // "TabletMode"
QT_MOC_LITERAL(22, 272, 24), // "SynchronousOutputChanges"
QT_MOC_LITERAL(23, 297, 14) // "XwaylandScales"

    },
    "KScreen::Config\0outputAdded\0\0"
    "KScreen::OutputPtr\0output\0outputRemoved\0"
    "outputId\0prioritiesChanged\0screen\0"
    "ScreenPtr\0outputs\0OutputList\0ValidityFlag\0"
    "None\0RequireAtLeastOneEnabledScreen\0"
    "Feature\0PrimaryDisplay\0Writable\0"
    "PerOutputScaling\0OutputReplication\0"
    "AutoRotation\0TabletMode\0"
    "SynchronousOutputChanges\0XwaylandScales"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KScreen__Config[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       2,   36, // properties
       2,   42, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x06 /* Public */,
       5,    1,   32,    2, 0x06 /* Public */,
       7,    0,   35,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,

 // properties: name, type, flags
       8, 0x80000000 | 9, 0x00095009,
      10, 0x80000000 | 11, 0x00095009,

 // enums: name, alias, flags, count, data
      12,   12, 0x2,    2,   52,
      15,   15, 0x2,    9,   56,

 // enum data: key, value
      13, uint(KScreen::Config::ValidityFlag::None),
      14, uint(KScreen::Config::ValidityFlag::RequireAtLeastOneEnabledScreen),
      13, uint(KScreen::Config::Feature::None),
      16, uint(KScreen::Config::Feature::PrimaryDisplay),
      17, uint(KScreen::Config::Feature::Writable),
      18, uint(KScreen::Config::Feature::PerOutputScaling),
      19, uint(KScreen::Config::Feature::OutputReplication),
      20, uint(KScreen::Config::Feature::AutoRotation),
      21, uint(KScreen::Config::Feature::TabletMode),
      22, uint(KScreen::Config::Feature::SynchronousOutputChanges),
      23, uint(KScreen::Config::Feature::XwaylandScales),

       0        // eod
};

void KScreen::Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Config *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->outputAdded((*reinterpret_cast< const KScreen::OutputPtr(*)>(_a[1]))); break;
        case 1: _t->outputRemoved((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->prioritiesChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Config::*)(const KScreen::OutputPtr & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Config::outputAdded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Config::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Config::outputRemoved)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Config::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Config::prioritiesChanged)) {
                *result = 2;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Config *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< ScreenPtr*>(_v) = _t->screen(); break;
        case 1: *reinterpret_cast< OutputList*>(_v) = _t->outputs(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject KScreen::Config::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_KScreen__Config.data,
    qt_meta_data_KScreen__Config,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KScreen::Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KScreen::Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KScreen__Config.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KScreen::Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KScreen::Config::outputAdded(const KScreen::OutputPtr & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KScreen::Config::outputRemoved(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KScreen::Config::prioritiesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
