// This file was generated by qtwaylandscanner
// source file is /usr/share/plasma-wayland-protocols/kde-output-order-v1.xml

#include "qwayland-kde-output-order-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
#if (WAYLAND_VERSION_MAJOR == 1 && WAYLAND_VERSION_MINOR > 10) || WAYLAND_VERSION_MAJOR > 1
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
        bindOpCode, interface, version, name, interface->name, version, nullptr);
#else
    return (void *) wl_proxy_marshal_constructor((struct wl_proxy *) registry,
        bindOpCode, interface, name, interface->name, version, nullptr);
#endif
}

    kde_output_order_v1::kde_output_order_v1(struct ::wl_registry *registry, int id, int version)
    {
        init(registry, id, version);
    }

    kde_output_order_v1::kde_output_order_v1(struct ::kde_output_order_v1 *obj)
        : m_kde_output_order_v1(obj)
    {
        init_listener();
    }

    kde_output_order_v1::kde_output_order_v1()
        : m_kde_output_order_v1(nullptr)
    {
    }

    kde_output_order_v1::~kde_output_order_v1()
    {
    }

    void kde_output_order_v1::init(struct ::wl_registry *registry, int id, int version)
    {
        m_kde_output_order_v1 = static_cast<struct ::kde_output_order_v1 *>(wlRegistryBind(registry, id, &kde_output_order_v1_interface, version));
        init_listener();
    }

    void kde_output_order_v1::init(struct ::kde_output_order_v1 *obj)
    {
        m_kde_output_order_v1 = obj;
        init_listener();
    }

    kde_output_order_v1 *kde_output_order_v1::fromObject(struct ::kde_output_order_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_kde_output_order_v1_listener)
            return nullptr;
        return static_cast<kde_output_order_v1 *>(kde_output_order_v1_get_user_data(object));
    }

    bool kde_output_order_v1::isInitialized() const
    {
        return m_kde_output_order_v1 != nullptr;
    }

    const struct wl_interface *kde_output_order_v1::interface()
    {
        return &::kde_output_order_v1_interface;
    }

    void kde_output_order_v1::destroy()
    {
        kde_output_order_v1_destroy(
            m_kde_output_order_v1);
        m_kde_output_order_v1 = nullptr;
    }

    void kde_output_order_v1::kde_output_order_v1_output(const QString &)
    {
    }

    void kde_output_order_v1::handle_output(
        void *data,
        struct ::kde_output_order_v1 *object,
        const char *output_name)
    {
        Q_UNUSED(object);
        static_cast<kde_output_order_v1 *>(data)->kde_output_order_v1_output(
            QString::fromUtf8(output_name));
    }

    void kde_output_order_v1::kde_output_order_v1_done()
    {
    }

    void kde_output_order_v1::handle_done(
        void *data,
        struct ::kde_output_order_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<kde_output_order_v1 *>(data)->kde_output_order_v1_done();
    }

    const struct kde_output_order_v1_listener kde_output_order_v1::m_kde_output_order_v1_listener = {
        kde_output_order_v1::handle_output,
        kde_output_order_v1::handle_done,
    };

    void kde_output_order_v1::init_listener()
    {
        kde_output_order_v1_add_listener(m_kde_output_order_v1, &m_kde_output_order_v1_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
